@@ -72,9 +72,9 @@ def noise_stacked_boxplot(error_rate_df,
 
 ### SIMPLIFIED FUNCTIONS (MAIN FUNCTIONS)
 #simplified function to plot phn boxplot 
-def full_phn_boxplot(asr_model,phn_counter_dict,DR=[1,7],styling_outliers = False):
-    asr_dict = load_asr_dict(asr_model=asr_model,DR=DR)
-    phn_counter_dict = compare_phonemes_perc(asr_dict,DR=DR)
+def full_phn_boxplot(asr_model,file_set="TRAIN",DR=[0,None],styling_outliers = False):
+    asr_dict = load_asr_dict(asr_model=asr_model,DR=DR,file_set=file_set)
+    phn_counter_dict = compare_phonemes_perc(asr_dict,DR=DR,file_set=file_set)
 
     return phn_boxplot(phn_counter_dict,styling_outliers=styling_outliers)
 
@@ -82,6 +82,7 @@ def full_noise_stackedplot(audio_dict,
                             noise_wav,
                             asr_phn_model,
                             asr_txt_model,
+                            cfg_filedir= 'noisyspeech.cfg',
                             DR = [0,None],
                             SPK = [0,None],
                             louder_volumes=[],
@@ -90,6 +91,7 @@ def full_noise_stackedplot(audio_dict,
     #Full description of inputs is in utils.phone error_rate func compare_phn_wrd_noise_multi
     error_rate_df = compare_phn_wrd_noise_multi(audio_dict = audio_dict,
                                                 noise_wav = noise_wav,
+                                                cfg_filedir = cfg_filedir,
                                                 asr_phn_model = asr_phn_model,
                                                 asr_txt_model = asr_txt_model,
                                                 DR = DR,
